@@ -18,18 +18,21 @@ use base 'FusionInventory::Agent::Task::Base';
 use English qw(-no_match_vars);
 use UNIVERSAL::require;
 
+use Config;
+
 use FusionInventory::Agent::AccountInfo;
 use FusionInventory::Agent::Config;
 use FusionInventory::Agent::Network;
 use FusionInventory::Agent::Storage;
 use FusionInventory::Agent::XML::Response::Prolog;
 use FusionInventory::Agent::XML::Query::Inventory;
+use FusionInventory::Agent::Tools;
 use FusionInventory::Logger;
 
 sub main {
     my $self = FusionInventory::Agent::Task::Inventory->new();
 
-    if ($self->{target}->{type} eq 'server' &&
+    if ((!$self->{config}->{force} && ($self->{target}->{type} eq 'server')) &&
         (
             !exists($self->{prologresp}->{parsedcontent}->{RESPONSE}) ||
             $self->{prologresp}->{parsedcontent}->{RESPONSE} !~ /^SEND$/
@@ -73,6 +76,9 @@ sub main {
 
     $self->feedInventory();
 
+# Put ACCOUNTINFO values in the inventory
+    my $accountinfo = $self->{target}->{accountinfo};
+    $accountinfo->setAccountInfo($self->{inventory});
 
     if ($self->{target}->{type} eq 'stdout') {
         $self->{inventory}->printXML();
@@ -84,11 +90,6 @@ sub main {
         }
     } elsif ($self->{target}->{type} eq 'server') {
 
-        my $accountinfo = $self->{target}->{accountinfo};
-
-        # Put ACCOUNTINFO values in the inventory
-        $accountinfo->setAccountInfo($self->{inventory});
-
         my $network = FusionInventory::Agent::Network->new({
             logger => $self->{logger},
             config => $self->{config},
@@ -122,7 +123,6 @@ sub initModList {
     my $config = $self->{config};
     my $storage = $self->{storage};
 
-    my @dirToScan;
     my @installed_mods;
     my @installed_files;
 
@@ -147,8 +147,20 @@ sub initModList {
                     }
                 }
             } else {
-                chomp(my $binpath=`which $binary 2>/dev/null`);
-                $ret = -x $binpath;
+                foreach (split(':', $ENV{PATH})) {
+                    next unless -x "$_/$binary";
+                    $ret = 1;
+                    last;
+                }
+                if (!$ret) {
+                    chomp(my $binpath=`which $binary 2>/dev/null`);
+                    # some which implementation, such as solaris, unfortunatly
+                    # return 'command foo not found', with no error status,
+                    # for unknown command. When testing path with spaces,
+                    # it returns a multiline message... So, let's check 
+                    # result content before assuming it is a file path
+                    $ret = $binpath =~ /not found/ ? 0 : -x $binpath;
+                }
             }
 
             return $ret;
@@ -195,23 +207,20 @@ sub initModList {
             @FusionInventory::Agent::Task::Inventory::ModuleToLoad::list;
     }
 
-    if ($config->{devlib}) {
-        # devlib enable, I only search for backend module in ./lib
-        push (@dirToScan, './lib');
-    } else {
-        foreach (@INC) {
-            next if ! -d || (-l && -d readlink) || /^(\.|lib)$/;
-            next if ! -d $_.'/FusionInventory/Agent/Task/Inventory';
-            push @dirToScan, $_;
-        }
-    }
-    if (@dirToScan) {
+    my $dirToScan = getFusionInventoryLibdir($config);
+    if ($dirToScan) {
         eval {
             require File::Find;
         };
         if ($EVAL_ERROR) {
             $logger->debug("Failed to load File::Find");
         } else {
+            my @dirList;
+            foreach (@$dirToScan) {
+                my $d = $_.'/FusionInventory/Agent';
+                next unless -d $d;
+                push @dirList, $d;
+            }
             # here I need to use $d to avoid a bug with AIX 5.2's perl 5.8.0. It
             # changes the @INC content if i use $_ directly
             # thanks to @rgs on irc.perl.org
@@ -224,7 +233,7 @@ sub initModList {
                     follow => 1,
                     follow_skip => 2
                 }
-                , @dirToScan);
+                , @dirList);
         }
     }
 
